==> jc-1.4.0.tar.gz: soot/options/NPCOptions.h <==
// public class soot.options.NPCOptions

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class e307bfe76c66ed15 soot_options_NPCOptions

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_options_NPCOptions_H_
#define _JC_soot_options_NPCOptions_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_Map$object;

// Typedefs
typedef struct _jc_soot_options_NPCOptions$sub_refs	_jc_soot_options_NPCOptions$sub_refs;
typedef struct _jc_soot_options_NPCOptions$sub_nonrefs	_jc_soot_options_NPCOptions$sub_nonrefs;
typedef struct _jc_soot_options_NPCOptions$refs	_jc_soot_options_NPCOptions$refs;
typedef struct _jc_soot_options_NPCOptions$nonrefs	_jc_soot_options_NPCOptions$nonrefs;
typedef struct _jc_soot_options_NPCOptions$object	_jc_soot_options_NPCOptions$object;

typedef const struct _jc_soot_options_NPCOptions$vmethods	_jc_soot_options_NPCOptions$vmethods;
typedef const struct _jc_soot_options_NPCOptions$vtable	_jc_soot_options_NPCOptions$vtable;
typedef const struct _jc_soot_options_NPCOptions$vtype	_jc_soot_options_NPCOptions$vtype;

// Constructors
extern void _jc_soot_options_NPCOptions$method$_init$39bc1e191d75104e(_jc_env *, struct _jc_soot_options_NPCOptions$object *, struct _jc_object *);

// Virtual methods
extern jboolean _jc_soot_options_NPCOptions$method$enabled$e29aaa88d18be18b(_jc_env *, struct _jc_soot_options_NPCOptions$object *);
extern jboolean _jc_soot_options_NPCOptions$method$only__5farray__5fref$35f59b5f5485ceb6(_jc_env *, struct _jc_soot_options_NPCOptions$object *);
extern jboolean _jc_soot_options_NPCOptions$method$profiling$5e9a36af2f57248a(_jc_env *, struct _jc_soot_options_NPCOptions$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_options_NPCOptions$method_info$enabled$e29aaa88d18be18b;
extern _jc_method _jc_soot_options_NPCOptions$method_info$only__5farray__5fref$35f59b5f5485ceb6;
extern _jc_method _jc_soot_options_NPCOptions$method_info$profiling$5e9a36af2f57248a;

// Virtual methods structure
struct _jc_soot_options_NPCOptions$vmethods {
	jboolean	(*enabled$e29aaa88d18be18b)(_jc_env *, struct _jc_soot_options_NPCOptions$object *);
	jboolean	(*only__5farray__5fref$35f59b5f5485ceb6)(_jc_env *, struct _jc_soot_options_NPCOptions$object *);
	jboolean	(*profiling$5e9a36af2f57248a)(_jc_env *, struct _jc_soot_options_NPCOptions$object *);
};

// Vtable
struct _jc_soot_options_NPCOptions$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_options_NPCOptions$vmethods	soot_options_NPCOptions;
};

// Vtype
struct _jc_soot_options_NPCOptions$vtype {
	_jc_type			type;
	_jc_soot_options_NPCOptions$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_options_NPCOptions$sub_refs {
	struct _jc_object	*options;
};

// Reference instance fields (object)
struct _jc_soot_options_NPCOptions$refs {
    _jc_soot_options_NPCOptions$sub_refs	soot_options_NPCOptions;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_options_NPCOptions$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_options_NPCOptions$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_options_NPCOptions$sub_nonrefs	soot_options_NPCOptions;
};

// Object instance structure
struct _jc_soot_options_NPCOptions$object {
	_jc_soot_options_NPCOptions$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_options_NPCOptions$vtype	*vtype;
	_jc_soot_options_NPCOptions$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_options_NPCOptions$vtype _jc_soot_options_NPCOptions$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_options_NPCOptions, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_options_NPCOptions$class_object;

#endif	/* _JC_soot_options_NPCOptions_H_ */

==> jc-1.4.6.tar.gz: soot/options/NPCOptions.h <==
// public class soot.options.NPCOptions

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class e307bfe76c66ed15 soot_options_NPCOptions

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_options_NPCOptions_H_
#define _JC_soot_options_NPCOptions_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_Map$object;

// Typedefs
typedef struct _jc_soot_options_NPCOptions$sub_refs	_jc_soot_options_NPCOptions$sub_refs;
typedef struct _jc_soot_options_NPCOptions$sub_nonrefs	_jc_soot_options_NPCOptions$sub_nonrefs;
typedef struct _jc_soot_options_NPCOptions$refs	_jc_soot_options_NPCOptions$refs;
typedef struct _jc_soot_options_NPCOptions$nonrefs	_jc_soot_options_NPCOptions$nonrefs;
typedef struct _jc_soot_options_NPCOptions$object	_jc_soot_options_NPCOptions$object;

typedef const struct _jc_soot_options_NPCOptions$vmethods	_jc_soot_options_NPCOptions$vmethods;
typedef const struct _jc_soot_options_NPCOptions$vtable	_jc_soot_options_NPCOptions$vtable;
typedef const struct _jc_soot_options_NPCOptions$vtype	_jc_soot_options_NPCOptions$vtype;

// Constructors
extern void _jc_soot_options_NPCOptions$method$_init$39bc1e191d75104e(_jc_env *, struct _jc_soot_options_NPCOptions$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_soot_options_NPCOptions$method$enabled$e29aaa88d18be18b(_jc_env *, struct _jc_soot_options_NPCOptions$object *) _JC_JCNI_ATTR;
extern jboolean _jc_soot_options_NPCOptions$method$only__5farray__5fref$35f59b5f5485ceb6(_jc_env *, struct _jc_soot_options_NPCOptions$object *) _JC_JCNI_ATTR;
extern jboolean _jc_soot_options_NPCOptions$method$profiling$5e9a36af2f57248a(_jc_env *, struct _jc_soot_options_NPCOptions$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_options_NPCOptions$method_info$enabled$e29aaa88d18be18b;
extern _jc_method _jc_soot_options_NPCOptions$method_info$only__5farray__5fref$35f59b5f5485ceb6;
extern _jc_method _jc_soot_options_NPCOptions$method_info$profiling$5e9a36af2f57248a;

// Virtual methods structure
struct _jc_soot_options_NPCOptions$vmethods {
	jboolean	(*enabled$e29aaa88d18be18b)(_jc_env *, struct _jc_soot_options_NPCOptions$object *) _JC_JCNI_ATTR;
	jboolean	(*only__5farray__5fref$35f59b5f5485ceb6)(_jc_env *, struct _jc_soot_options_NPCOptions$object *) _JC_JCNI_ATTR;
	jboolean	(*profiling$5e9a36af2f57248a)(_jc_env *, struct _jc_soot_options_NPCOptions$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_options_NPCOptions$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_options_NPCOptions$vmethods	soot_options_NPCOptions;
};

// Vtype
struct _jc_soot_options_NPCOptions$vtype {
	_jc_type			type;
	_jc_soot_options_NPCOptions$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_options_NPCOptions$sub_refs {
	struct _jc_object	*options;
};

// Reference instance fields (object)
struct _jc_soot_options_NPCOptions$refs {
    _jc_soot_options_NPCOptions$sub_refs	soot_options_NPCOptions;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_options_NPCOptions$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_options_NPCOptions$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_options_NPCOptions$sub_nonrefs	soot_options_NPCOptions;
};

// Object instance structure
struct _jc_soot_options_NPCOptions$object {
	_jc_soot_options_NPCOptions$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_options_NPCOptions$vtype	*vtype;
	_jc_soot_options_NPCOptions$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_options_NPCOptions$vtype _jc_soot_options_NPCOptions$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_options_NPCOptions, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_options_NPCOptions$class_object;

#endif	/* _JC_soot_options_NPCOptions_H_ */
